@@ -47,10 +47,9 @@ G_BEGIN_DECLS
 #define GDK_IS_EVENT_TYPE(event, type)  (gdk_event_get_event_type ((event)) == (type))
 
 /**
- * GDK_PRIORITY_EVENTS:
+ * GDK_PRIORITY_EVENTS: (value 0)
  *
- * This is the priority that events from the X server are given in the
- * [GLib Main Loop][glib-The-Main-Event-Loop].
+ * This is the priority that events from the X server are given in the main loop.
  */
 #define GDK_PRIORITY_EVENTS	(G_PRIORITY_DEFAULT)
 
@@ -58,8 +57,7 @@ G_BEGIN_DECLS
  * GDK_PRIORITY_REDRAW: (value 120)
  *
  * This is the priority that the idle handler processing surface updates
- * is given in the
- * [GLib Main Loop][glib-The-Main-Event-Loop].
+ * is given in the main loop.
  */
 #define GDK_PRIORITY_REDRAW     (G_PRIORITY_HIGH_IDLE + 20)
 
@@ -106,7 +104,6 @@ typedef struct _GdkEventSequence        GdkEventSequence;
 typedef struct _GdkEvent                GdkEvent;
 
 #define GDK_TYPE_BUTTON_EVENT (gdk_button_event_get_type())
-#define GDK_TYPE_CONFIGURE_EVENT (gdk_configure_event_get_type())
 #define GDK_TYPE_CROSSING_EVENT (gdk_crossing_event_get_type())
 #define GDK_TYPE_DELETE_EVENT (gdk_delete_event_get_type())
 #define GDK_TYPE_DND_EVENT (gdk_dnd_event_get_type())
@@ -121,7 +118,6 @@ typedef struct _GdkEvent                GdkEvent;
 #define GDK_TYPE_TOUCHPAD_EVENT (gdk_touchpad_event_get_type())
 
 typedef struct _GdkButtonEvent          GdkButtonEvent;
-typedef struct _GdkConfigureEvent       GdkConfigureEvent;
 typedef struct _GdkCrossingEvent        GdkCrossingEvent;
 typedef struct _GdkDeleteEvent          GdkDeleteEvent;
 typedef struct _GdkDNDEvent             GdkDNDEvent;
@@ -148,7 +144,6 @@ typedef struct _GdkTouchpadEvent        GdkTouchpadEvent;
  * @GDK_ENTER_NOTIFY: the pointer has entered the surface.
  * @GDK_LEAVE_NOTIFY: the pointer has left the surface.
  * @GDK_FOCUS_CHANGE: the keyboard focus has entered or left the surface.
- * @GDK_CONFIGURE: the size of the surface has changed.
  * @GDK_PROXIMITY_IN: an input device has moved into contact with a sensing
  *   surface (e.g. a touchscreen or graphics tablet).
  * @GDK_PROXIMITY_OUT: an input device has moved out of contact with a sensing
@@ -188,7 +183,6 @@ typedef enum
   GDK_ENTER_NOTIFY,
   GDK_LEAVE_NOTIFY,
   GDK_FOCUS_CHANGE,
-  GDK_CONFIGURE,
   GDK_PROXIMITY_IN,
   GDK_PROXIMITY_OUT,
   GDK_DRAG_ENTER,
@@ -220,9 +214,11 @@ typedef enum
  * @GDK_TOUCHPAD_GESTURE_PHASE_CANCEL: The gesture was cancelled, all
  *   changes should be undone.
  *
- * Specifies the current state of a touchpad gesture. All gestures are
- * guaranteed to begin with an event with phase %GDK_TOUCHPAD_GESTURE_PHASE_BEGIN,
- * followed by 0 or several events with phase %GDK_TOUCHPAD_GESTURE_PHASE_UPDATE.
+ * Specifies the current state of a touchpad gesture.
+ *
+ * All gestures are guaranteed to begin with an event with phase
+ * %GDK_TOUCHPAD_GESTURE_PHASE_BEGIN, followed by 0 or several events
+ * with phase %GDK_TOUCHPAD_GESTURE_PHASE_UPDATE.
  *
  * A finished gesture may have 2 possible outcomes, an event with phase
  * %GDK_TOUCHPAD_GESTURE_PHASE_END will be emitted when the gesture is
@@ -252,7 +248,7 @@ typedef enum
  * @GDK_SCROLL_LEFT: the surface is scrolled to the left.
  * @GDK_SCROLL_RIGHT: the surface is scrolled to the right.
  * @GDK_SCROLL_SMOOTH: the scrolling is determined by the delta values
- *   in scroll events. See gdk_event_get_scroll_deltas()
+ *   in scroll events. See gdk_scroll_event_get_deltas()
  *
  * Specifies the direction for scroll events.
  */
@@ -301,9 +297,9 @@ typedef enum
  * @GDK_CROSSING_NORMAL: crossing because of pointer motion.
  * @GDK_CROSSING_GRAB: crossing because a grab is activated.
  * @GDK_CROSSING_UNGRAB: crossing because a grab is deactivated.
- * @GDK_CROSSING_GTK_GRAB: crossing because a GTK+ grab is activated.
- * @GDK_CROSSING_GTK_UNGRAB: crossing because a GTK+ grab is deactivated.
- * @GDK_CROSSING_STATE_CHANGED: crossing because a GTK+ widget changed
+ * @GDK_CROSSING_GTK_GRAB: crossing because a GTK grab is activated.
+ * @GDK_CROSSING_GTK_UNGRAB: crossing because a GTK grab is deactivated.
+ * @GDK_CROSSING_STATE_CHANGED: crossing because a GTK widget changed
  *   state (e.g. sensitivity).
  * @GDK_CROSSING_TOUCH_BEGIN: crossing because a touch sequence has begun,
  *   this event is synthetic as the pointer might have not left the surface.
@@ -429,12 +425,6 @@ GdkNotifyType           gdk_crossing_event_get_detail   (GdkEvent *event);
 GDK_AVAILABLE_IN_ALL
 gboolean                gdk_crossing_event_get_focus    (GdkEvent *event);
 GDK_AVAILABLE_IN_ALL
-GType                   gdk_configure_event_get_type    (void) G_GNUC_CONST;
-GDK_AVAILABLE_IN_ALL
-void                    gdk_configure_event_get_size    (GdkEvent *event,
-                                                         int      *width,
-                                                         int      *height);
-GDK_AVAILABLE_IN_ALL
 GType                   gdk_touchpad_event_get_type     (void) G_GNUC_CONST;
 GDK_AVAILABLE_IN_ALL
 GdkTouchpadGesturePhase
@@ -504,8 +494,9 @@ gboolean                gdk_events_get_center           (GdkEvent *event1,
  *     (specifically, the currently active group) is ignored
  * @GDK_KEY_MATCH_EXACT: The key event matches
  *
- * The possible return values from gdk_key_event_matches()
- * describe how well an event matches a given keyval and modifiers.
+ * Describes how well an event matches a given keyval and modifiers.
+ *
+ * `GdkKeyMatch` values are returned by [method@Gdk.KeyEvent.matches].
  */
 typedef enum {
   GDK_KEY_MATCH_NONE,
