@@ -99,7 +99,6 @@ struct _GtkCellRenderer
  * @get_preferred_height: Called to get a renderer’s natural height.
  * @get_preferred_width_for_height: Called to get a renderer’s natural width for height.
  * @get_aligned_area: Called to get the aligned area used by @cell inside @cell_area.
- * @get_size: Called to get the width and height needed to render the cell. Deprecated: 3.0.
  * @snapshot: Called to snapshot the content of the #GtkCellRenderer.
  * @activate: Called to activate the content of the #GtkCellRenderer.
  * @start_editing: Called to initiate editing the content of the #GtkCellRenderer.
@@ -117,34 +116,27 @@ struct _GtkCellRendererClass
   GtkSizeRequestMode (* get_request_mode)                (GtkCellRenderer      *cell);
   void               (* get_preferred_width)             (GtkCellRenderer      *cell,
                                                           GtkWidget            *widget,
-                                                          gint                 *minimum_size,
-                                                          gint                 *natural_size);
+                                                          int                  *minimum_size,
+                                                          int                  *natural_size);
   void               (* get_preferred_height_for_width)  (GtkCellRenderer      *cell,
                                                           GtkWidget            *widget,
-                                                          gint                  width,
-                                                          gint                 *minimum_height,
-                                                          gint                 *natural_height);
+                                                          int                   width,
+                                                          int                  *minimum_height,
+                                                          int                  *natural_height);
   void               (* get_preferred_height)            (GtkCellRenderer      *cell,
                                                           GtkWidget            *widget,
-                                                          gint                 *minimum_size,
-                                                          gint                 *natural_size);
+                                                          int                  *minimum_size,
+                                                          int                  *natural_size);
   void               (* get_preferred_width_for_height)  (GtkCellRenderer      *cell,
                                                           GtkWidget            *widget,
-                                                          gint                  height,
-                                                          gint                 *minimum_width,
-                                                          gint                 *natural_width);
+                                                          int                   height,
+                                                          int                  *minimum_width,
+                                                          int                  *natural_width);
   void               (* get_aligned_area)                (GtkCellRenderer      *cell,
                                                           GtkWidget            *widget,
 							  GtkCellRendererState  flags,
                                                           const GdkRectangle   *cell_area,
                                                           GdkRectangle         *aligned_area);
-  void               (* get_size)                        (GtkCellRenderer      *cell,
-                                                          GtkWidget            *widget,
-                                                          const GdkRectangle   *cell_area,
-                                                          gint                 *x_offset,
-                                                          gint                 *y_offset,
-                                                          gint                 *width,
-                                                          gint                 *height);
   void               (* snapshot)                        (GtkCellRenderer      *cell,
                                                           GtkSnapshot          *snapshot,
                                                           GtkWidget            *widget,
@@ -154,14 +146,14 @@ struct _GtkCellRendererClass
   gboolean           (* activate)                        (GtkCellRenderer      *cell,
                                                           GdkEvent             *event,
                                                           GtkWidget            *widget,
-                                                          const gchar          *path,
+                                                          const char           *path,
                                                           const GdkRectangle   *background_area,
                                                           const GdkRectangle   *cell_area,
                                                           GtkCellRendererState  flags);
   GtkCellEditable *  (* start_editing)                   (GtkCellRenderer      *cell,
                                                           GdkEvent             *event,
                                                           GtkWidget            *widget,
-                                                          const gchar          *path,
+                                                          const char           *path,
                                                           const GdkRectangle   *background_area,
                                                           const GdkRectangle   *cell_area,
                                                           GtkCellRendererState  flags);
@@ -170,16 +162,10 @@ struct _GtkCellRendererClass
   void (* editing_canceled) (GtkCellRenderer *cell);
   void (* editing_started)  (GtkCellRenderer *cell,
 			     GtkCellEditable *editable,
-			     const gchar     *path);
+			     const char      *path);
 
   /*< private >*/
-
-  GtkCellRendererClassPrivate *priv;
-
-  /* Padding for future expansion */
-  void (*_gtk_reserved2) (void);
-  void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
+  gpointer padding[8];
 };
 
 GDK_AVAILABLE_IN_ALL
@@ -190,25 +176,25 @@ GtkSizeRequestMode gtk_cell_renderer_get_request_mode               (GtkCellRend
 GDK_AVAILABLE_IN_ALL
 void               gtk_cell_renderer_get_preferred_width            (GtkCellRenderer    *cell,
                                                                      GtkWidget          *widget,
-                                                                     gint               *minimum_size,
-                                                                     gint               *natural_size);
+                                                                     int                *minimum_size,
+                                                                     int                *natural_size);
 GDK_AVAILABLE_IN_ALL
 void               gtk_cell_renderer_get_preferred_height_for_width (GtkCellRenderer    *cell,
                                                                      GtkWidget          *widget,
-                                                                     gint                width,
-                                                                     gint               *minimum_height,
-                                                                     gint               *natural_height);
+                                                                     int                 width,
+                                                                     int                *minimum_height,
+                                                                     int                *natural_height);
 GDK_AVAILABLE_IN_ALL
 void               gtk_cell_renderer_get_preferred_height           (GtkCellRenderer    *cell,
                                                                      GtkWidget          *widget,
-                                                                     gint               *minimum_size,
-                                                                     gint               *natural_size);
+                                                                     int                *minimum_size,
+                                                                     int                *natural_size);
 GDK_AVAILABLE_IN_ALL
 void               gtk_cell_renderer_get_preferred_width_for_height (GtkCellRenderer    *cell,
                                                                      GtkWidget          *widget,
-                                                                     gint                height,
-                                                                     gint               *minimum_width,
-                                                                     gint               *natural_width);
+                                                                     int                 height,
+                                                                     int                *minimum_width,
+                                                                     int                *natural_width);
 GDK_AVAILABLE_IN_ALL
 void               gtk_cell_renderer_get_preferred_size             (GtkCellRenderer    *cell,
                                                                      GtkWidget          *widget,
@@ -231,7 +217,7 @@ GDK_AVAILABLE_IN_ALL
 gboolean         gtk_cell_renderer_activate       (GtkCellRenderer      *cell,
 						   GdkEvent             *event,
 						   GtkWidget            *widget,
-						   const gchar          *path,
+						   const char           *path,
 						   const GdkRectangle   *background_area,
 						   const GdkRectangle   *cell_area,
 						   GtkCellRendererState  flags);
@@ -239,37 +225,37 @@ GDK_AVAILABLE_IN_ALL
 GtkCellEditable *gtk_cell_renderer_start_editing  (GtkCellRenderer      *cell,
 						   GdkEvent             *event,
 						   GtkWidget            *widget,
-						   const gchar          *path,
+						   const char           *path,
 						   const GdkRectangle   *background_area,
 						   const GdkRectangle   *cell_area,
 						   GtkCellRendererState  flags);
 
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_set_fixed_size (GtkCellRenderer      *cell,
-						   gint                  width,
-						   gint                  height);
+						   int                   width,
+						   int                   height);
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_get_fixed_size (GtkCellRenderer      *cell,
-						   gint                 *width,
-						   gint                 *height);
+						   int                  *width,
+						   int                  *height);
 
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_set_alignment  (GtkCellRenderer      *cell,
-                                                   gfloat                xalign,
-                                                   gfloat                yalign);
+                                                   float                 xalign,
+                                                   float                 yalign);
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_get_alignment  (GtkCellRenderer      *cell,
-                                                   gfloat               *xalign,
-                                                   gfloat               *yalign);
+                                                   float                *xalign,
+                                                   float                *yalign);
 
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_set_padding    (GtkCellRenderer      *cell,
-                                                   gint                  xpad,
-                                                   gint                  ypad);
+                                                   int                   xpad,
+                                                   int                   ypad);
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_get_padding    (GtkCellRenderer      *cell,
-                                                   gint                 *xpad,
-                                                   gint                 *ypad);
+                                                   int                  *xpad,
+                                                   int                  *ypad);
 
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_set_visible    (GtkCellRenderer      *cell,
@@ -286,6 +272,21 @@ gboolean         gtk_cell_renderer_get_sensitive  (GtkCellRenderer      *cell);
 GDK_AVAILABLE_IN_ALL
 gboolean         gtk_cell_renderer_is_activatable (GtkCellRenderer      *cell);
 
+GDK_AVAILABLE_IN_ALL
+void             gtk_cell_renderer_set_is_expander (GtkCellRenderer     *cell,
+                                                    gboolean             is_expander);
+GDK_AVAILABLE_IN_ALL
+gboolean         gtk_cell_renderer_get_is_expander (GtkCellRenderer     *cell);
+
+GDK_AVAILABLE_IN_ALL
+void             gtk_cell_renderer_set_is_expanded (GtkCellRenderer     *cell,
+                                                    gboolean             is_expanded);
+GDK_AVAILABLE_IN_ALL
+gboolean         gtk_cell_renderer_get_is_expanded (GtkCellRenderer     *cell);
+
+
+
+
 /* For use by cell renderer implementations only */
 GDK_AVAILABLE_IN_ALL
 void             gtk_cell_renderer_stop_editing   (GtkCellRenderer      *cell,
@@ -295,23 +296,16 @@ void             gtk_cell_renderer_stop_editing   (GtkCellRenderer      *cell,
 void            _gtk_cell_renderer_calc_offset    (GtkCellRenderer      *cell,
                                                    const GdkRectangle   *cell_area,
                                                    GtkTextDirection      direction,
-                                                   gint                  width,
-                                                   gint                  height,
-                                                   gint                 *x_offset,
-                                                   gint                 *y_offset);
+                                                   int                   width,
+                                                   int                   height,
+                                                   int                  *x_offset,
+                                                   int                  *y_offset);
 
 GDK_AVAILABLE_IN_ALL
 GtkStateFlags   gtk_cell_renderer_get_state       (GtkCellRenderer      *cell,
                                                    GtkWidget            *widget,
                                                    GtkCellRendererState  cell_state);
 
-GDK_AVAILABLE_IN_ALL
-void            gtk_cell_renderer_class_set_accessible_type 
-                                                  (GtkCellRendererClass *renderer_class,
-                                                   GType                 type);
-GType           _gtk_cell_renderer_get_accessible_type
-                                                  (GtkCellRenderer *     renderer);
-
 G_END_DECLS
 
 #endif /* __GTK_CELL_RENDERER_H__ */
