@@ -37,33 +37,6 @@
 
 G_BEGIN_DECLS
 
-/*
- * This is the PUBLIC representation of a text buffer.
- * GtkTextBTree is the PRIVATE internal representation of it.
- */
-
-/**
- * GtkTextBufferTargetInfo:
- * @GTK_TEXT_BUFFER_TARGET_INFO_BUFFER_CONTENTS: Buffer contents
- * @GTK_TEXT_BUFFER_TARGET_INFO_RICH_TEXT: Rich text
- * @GTK_TEXT_BUFFER_TARGET_INFO_TEXT: Text
- *
- * These values are used as “info” for the targets contained in the
- * lists returned by gtk_text_buffer_get_copy_target_list() and
- * gtk_text_buffer_get_paste_target_list().
- *
- * The values counts down from `-1` to avoid clashes
- * with application added drag destinations which usually start at 0.
- */
-typedef enum
-{
-  GTK_TEXT_BUFFER_TARGET_INFO_BUFFER_CONTENTS = - 1,
-  GTK_TEXT_BUFFER_TARGET_INFO_RICH_TEXT       = - 2,
-  GTK_TEXT_BUFFER_TARGET_INFO_TEXT            = - 3
-} GtkTextBufferTargetInfo;
-
-typedef struct _GtkTextBTree GtkTextBTree;
-
 #define GTK_TYPE_TEXT_BUFFER            (gtk_text_buffer_get_type ())
 #define GTK_TEXT_BUFFER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_TEXT_BUFFER, GtkTextBuffer))
 #define GTK_TEXT_BUFFER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_TEXT_BUFFER, GtkTextBufferClass))
@@ -97,6 +70,10 @@ struct _GtkTextBuffer
  * @begin_user_action: The class handler for the #GtkTextBuffer::begin-user-action signal.
  * @end_user_action: The class handler for the #GtkTextBuffer::end-user-action signal.
  * @paste_done: The class handler for the #GtkTextBuffer::paste-done signal.
+ * @undo: The class handler for the #GtkTextBuffer::undo signal
+ * @redo: The class handler for the #GtkTextBuffer::redo signal
+ *
+ * The class structure for #GtkTextBuffer.
  */
 struct _GtkTextBufferClass
 {
@@ -104,8 +81,8 @@ struct _GtkTextBufferClass
 
   void (* insert_text)            (GtkTextBuffer      *buffer,
                                    GtkTextIter        *pos,
-                                   const gchar        *new_text,
-                                   gint                new_text_length);
+                                   const char         *new_text,
+                                   int                 new_text_length);
 
   void (* insert_paintable)       (GtkTextBuffer      *buffer,
                                    GtkTextIter        *iter,
@@ -167,9 +144,9 @@ GType        gtk_text_buffer_get_type       (void) G_GNUC_CONST;
 GDK_AVAILABLE_IN_ALL
 GtkTextBuffer *gtk_text_buffer_new            (GtkTextTagTable *table);
 GDK_AVAILABLE_IN_ALL
-gint           gtk_text_buffer_get_line_count (GtkTextBuffer   *buffer);
+int            gtk_text_buffer_get_line_count (GtkTextBuffer   *buffer);
 GDK_AVAILABLE_IN_ALL
-gint           gtk_text_buffer_get_char_count (GtkTextBuffer   *buffer);
+int            gtk_text_buffer_get_char_count (GtkTextBuffer   *buffer);
 
 
 GDK_AVAILABLE_IN_ALL
@@ -178,30 +155,30 @@ GtkTextTagTable* gtk_text_buffer_get_tag_table (GtkTextBuffer  *buffer);
 /* Delete whole buffer, then insert */
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_set_text          (GtkTextBuffer *buffer,
-                                        const gchar   *text,
-                                        gint           len);
+                                        const char    *text,
+                                        int            len);
 
 /* Insert into the buffer */
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_insert            (GtkTextBuffer *buffer,
                                         GtkTextIter   *iter,
-                                        const gchar   *text,
-                                        gint           len);
+                                        const char    *text,
+                                        int            len);
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_insert_at_cursor  (GtkTextBuffer *buffer,
-                                        const gchar   *text,
-                                        gint           len);
+                                        const char    *text,
+                                        int            len);
 
 GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_interactive           (GtkTextBuffer *buffer,
                                                        GtkTextIter   *iter,
-                                                       const gchar   *text,
-                                                       gint           len,
+                                                       const char    *text,
+                                                       int            len,
                                                        gboolean       default_editable);
 GDK_AVAILABLE_IN_ALL
 gboolean gtk_text_buffer_insert_interactive_at_cursor (GtkTextBuffer *buffer,
-                                                       const gchar   *text,
-                                                       gint           len,
+                                                       const char    *text,
+                                                       int            len,
                                                        gboolean       default_editable);
 
 GDK_AVAILABLE_IN_ALL
@@ -219,24 +196,24 @@ gboolean gtk_text_buffer_insert_range_interactive (GtkTextBuffer     *buffer,
 GDK_AVAILABLE_IN_ALL
 void    gtk_text_buffer_insert_with_tags          (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
-                                                   const gchar       *text,
-                                                   gint               len,
+                                                   const char        *text,
+                                                   int                len,
                                                    GtkTextTag        *first_tag,
                                                    ...) G_GNUC_NULL_TERMINATED;
 
 GDK_AVAILABLE_IN_ALL
 void    gtk_text_buffer_insert_with_tags_by_name  (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
-                                                   const gchar       *text,
-                                                   gint               len,
-                                                   const gchar       *first_tag_name,
+                                                   const char        *text,
+                                                   int                len,
+                                                   const char        *first_tag_name,
                                                    ...) G_GNUC_NULL_TERMINATED;
 
 GDK_AVAILABLE_IN_ALL
 void     gtk_text_buffer_insert_markup            (GtkTextBuffer     *buffer,
                                                    GtkTextIter       *iter,
-                                                   const gchar       *markup,
-                                                   gint               len);
+                                                   const char        *markup,
+                                                   int                len);
 
 /* Delete from the buffer */
 GDK_AVAILABLE_IN_ALL
@@ -256,13 +233,13 @@ gboolean gtk_text_buffer_backspace          (GtkTextBuffer *buffer,
 
 /* Obtain strings from the buffer */
 GDK_AVAILABLE_IN_ALL
-gchar          *gtk_text_buffer_get_text            (GtkTextBuffer     *buffer,
+char           *gtk_text_buffer_get_text            (GtkTextBuffer     *buffer,
                                                      const GtkTextIter *start,
                                                      const GtkTextIter *end,
                                                      gboolean           include_hidden_chars);
 
 GDK_AVAILABLE_IN_ALL
-gchar          *gtk_text_buffer_get_slice           (GtkTextBuffer     *buffer,
+char           *gtk_text_buffer_get_slice           (GtkTextBuffer     *buffer,
                                                      const GtkTextIter *start,
                                                      const GtkTextIter *end,
                                                      gboolean           include_hidden_chars);
@@ -291,7 +268,7 @@ void           gtk_text_buffer_add_mark    (GtkTextBuffer     *buffer,
                                             const GtkTextIter *where);
 GDK_AVAILABLE_IN_ALL
 GtkTextMark   *gtk_text_buffer_create_mark (GtkTextBuffer     *buffer,
-                                            const gchar       *mark_name,
+                                            const char        *mark_name,
                                             const GtkTextIter *where,
                                             gboolean           left_gravity);
 GDK_AVAILABLE_IN_ALL
@@ -303,15 +280,15 @@ void           gtk_text_buffer_delete_mark (GtkTextBuffer     *buffer,
                                             GtkTextMark       *mark);
 GDK_AVAILABLE_IN_ALL
 GtkTextMark*   gtk_text_buffer_get_mark    (GtkTextBuffer     *buffer,
-                                            const gchar       *name);
+                                            const char        *name);
 
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_move_mark_by_name   (GtkTextBuffer     *buffer,
-                                          const gchar       *name,
+                                          const char        *name,
                                           const GtkTextIter *where);
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_delete_mark_by_name (GtkTextBuffer     *buffer,
-                                          const gchar       *name);
+                                          const char        *name);
 
 GDK_AVAILABLE_IN_ALL
 GtkTextMark* gtk_text_buffer_get_insert          (GtkTextBuffer *buffer);
@@ -342,12 +319,12 @@ void gtk_text_buffer_remove_tag            (GtkTextBuffer     *buffer,
                                             const GtkTextIter *end);
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_apply_tag_by_name     (GtkTextBuffer     *buffer,
-                                            const gchar       *name,
+                                            const char        *name,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_remove_tag_by_name    (GtkTextBuffer     *buffer,
-                                            const gchar       *name,
+                                            const char        *name,
                                             const GtkTextIter *start,
                                             const GtkTextIter *end);
 GDK_AVAILABLE_IN_ALL
@@ -361,31 +338,31 @@ void gtk_text_buffer_remove_all_tags       (GtkTextBuffer     *buffer,
  */
 GDK_AVAILABLE_IN_ALL
 GtkTextTag    *gtk_text_buffer_create_tag (GtkTextBuffer *buffer,
-                                           const gchar   *tag_name,
-                                           const gchar   *first_property_name,
+                                           const char    *tag_name,
+                                           const char    *first_property_name,
                                            ...);
 
 /* Obtain iterators pointed at various places, then you can move the
  * iterator around using the GtkTextIter operators
  */
 GDK_AVAILABLE_IN_ALL
-void gtk_text_buffer_get_iter_at_line_offset (GtkTextBuffer *buffer,
-                                              GtkTextIter   *iter,
-                                              gint           line_number,
-                                              gint           char_offset);
+gboolean gtk_text_buffer_get_iter_at_line_offset (GtkTextBuffer *buffer,
+                                                  GtkTextIter   *iter,
+                                                  int            line_number,
+                                                  int            char_offset);
 GDK_AVAILABLE_IN_ALL
-void gtk_text_buffer_get_iter_at_line_index  (GtkTextBuffer *buffer,
-                                              GtkTextIter   *iter,
-                                              gint           line_number,
-                                              gint           byte_index);
+gboolean gtk_text_buffer_get_iter_at_line_index  (GtkTextBuffer *buffer,
+                                                  GtkTextIter   *iter,
+                                                  int            line_number,
+                                                  int            byte_index);
 GDK_AVAILABLE_IN_ALL
-void gtk_text_buffer_get_iter_at_offset      (GtkTextBuffer *buffer,
-                                              GtkTextIter   *iter,
-                                              gint           char_offset);
+void     gtk_text_buffer_get_iter_at_offset      (GtkTextBuffer *buffer,
+                                                  GtkTextIter   *iter,
+                                                  int            char_offset);
 GDK_AVAILABLE_IN_ALL
-void gtk_text_buffer_get_iter_at_line        (GtkTextBuffer *buffer,
-                                              GtkTextIter   *iter,
-                                              gint           line_number);
+gboolean gtk_text_buffer_get_iter_at_line        (GtkTextBuffer *buffer,
+                                                  GtkTextIter   *iter,
+                                                  int            line_number);
 GDK_AVAILABLE_IN_ALL
 void gtk_text_buffer_get_start_iter          (GtkTextBuffer *buffer,
                                               GtkTextIter   *iter);
