@@ -25,44 +25,31 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#ifndef __GTK_VOLUME_BUTTON_H__
+#define __GTK_VOLUME_BUTTON_H__
+
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
-#ifndef __GTK_VOLUME_BUTTON_H__
-#define __GTK_VOLUME_BUTTON_H__
-
 #include <gtk/gtkscalebutton.h>
 
 G_BEGIN_DECLS
 
 #define GTK_TYPE_VOLUME_BUTTON                 (gtk_volume_button_get_type ())
 #define GTK_VOLUME_BUTTON(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_VOLUME_BUTTON, GtkVolumeButton))
-#define GTK_VOLUME_BUTTON_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_VOLUME_BUTTON, GtkVolumeButtonClass))
 #define GTK_IS_VOLUME_BUTTON(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_VOLUME_BUTTON))
-#define GTK_IS_VOLUME_BUTTON_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_VOLUME_BUTTON))
-#define GTK_VOLUME_BUTTON_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_VOLUME_BUTTON, GtkVolumeButtonClass))
 
 typedef struct _GtkVolumeButton       GtkVolumeButton;
-typedef struct _GtkVolumeButtonClass  GtkVolumeButtonClass;
 
 struct _GtkVolumeButton
 {
   GtkScaleButton  parent;
 };
 
-struct _GtkVolumeButtonClass
-{
-  GtkScaleButtonClass parent_class;
-
-  /* Padding for future expansion */
-  void (*_gtk_reserved1) (void);
-  void (*_gtk_reserved2) (void);
-  void (*_gtk_reserved3) (void);
-  void (*_gtk_reserved4) (void);
-};
-
+GDK_AVAILABLE_IN_ALL
 GType		gtk_volume_button_get_type	(void) G_GNUC_CONST;
+GDK_AVAILABLE_IN_ALL
 GtkWidget*	gtk_volume_button_new		(void);
 
 G_END_DECLS
