@@ -62,25 +62,10 @@ typedef struct _GtkWidgetClassPrivate  GtkWidgetClassPrivate;
  * @width: the width of the widget’s allocated area.
  * @height: the height of the widget’s allocated area.
  *
- * A #GtkAllocation-struct of a widget represents region
- * which has been allocated to the widget by its parent. It is a subregion
- * of its parents allocation. See
- * [GtkWidget’s geometry management section][geometry-management] for
- * more information.
+ * The rectangle representing the area allocated for a widget by its parent.
  */
 typedef         GdkRectangle       GtkAllocation;
 
-/**
- * GtkCallback:
- * @widget: the widget to operate on
- * @data: (closure): user-supplied data
- *
- * The type of the callback functions used for e.g. iterating over
- * the children of a container, see gtk_container_foreach().
- */
-typedef void    (*GtkCallback)     (GtkWidget        *widget,
-                                    gpointer          data);
-
 /**
  * GtkTickCallback:
  * @widget: the widget
@@ -131,9 +116,6 @@ struct _GtkWidget
  *   element in the widget class structure in order for the class mechanism
  *   to work correctly. This allows a GtkWidgetClass pointer to be cast to
  *   a GObjectClass pointer.
- * @activate_signal: The signal to emit when a widget of this class is
- *   activated, gtk_widget_activate() handles the emission.
- *   Implementation of this signal is optional.
  * @show: Signal emitted when widget is shown
  * @hide: Signal emitted when widget is hidden.
  * @map: Signal emitted when widget is going to be mapped, that is
@@ -152,12 +134,15 @@ struct _GtkWidget
  *   to be hidden).
  * @root: Called when the widget gets added to a #GtkRoot widget. Must chain up
  * @unroot: Called when the widget is about to be removed from its #GtkRoot widget. Must chain up
- * @size_allocate: Signal emitted to get the widget allocation.
+ * @size_allocate: Called to set the allocation, if the widget does
+ *   not have a layout manager.
  * @state_flags_changed: Signal emitted when the widget state changes,
  *   see gtk_widget_get_state_flags().
  * @direction_changed: Signal emitted when the text direction of a
  *   widget changes.
- * @get_request_mode: This allows a widget to tell its parent container whether
+ * @get_request_mode: Called to get the request mode, if the widget
+ *   does not have a layout manager.
+ *   This allows a widget to tell its parent container whether
  *   it prefers to be allocated in %GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH or
  *   %GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT mode.
  *   %GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH means the widget prefers to have
@@ -170,10 +155,11 @@ struct _GtkWidget
  *   which trades height-for-width or width-for-height must respond properly
  *   to a for_size value >= -1 passed to #GtkWidgetClass.measure, for both
  *   possible orientations.
- * @measure: This is called by containers to obtain the minimum and natural
- *   size of the widget. Depending on the orientation parameter, the passed
- *   for_size can be interpreted as width or height. A widget will never be
- *   allocated less than its minimum size.
+ * @measure: Called to obtain the minimum and natural size of the widget,
+ *   if the widget does not have a layout manager.
+ *   Depending on the orientation parameter, the passed for_size can be
+ *   interpreted as width or height. A widget will never be allocated less
+ *   than its minimum size.
  * @mnemonic_activate: Activates the @widget if @group_cycling is
  *   %FALSE, and just grabs the focus if @group_cycling is %TRUE.
  * @grab_focus: Causes @widget to have the keyboard focus for the
@@ -201,8 +187,6 @@ struct _GtkWidgetClass
 
   /*< public >*/
 
-  guint activate_signal;
-
   /* basics */
   void (* show)                (GtkWidget        *widget);
   void (* hide)                (GtkWidget        *widget);
@@ -282,10 +266,6 @@ struct _GtkWidgetClass
 GDK_AVAILABLE_IN_ALL
 GType      gtk_widget_get_type            (void) G_GNUC_CONST;
 GDK_AVAILABLE_IN_ALL
-GtkWidget* gtk_widget_new                 (GType                type,
-                                           const char          *first_property_name,
-                                           ...);
-GDK_AVAILABLE_IN_ALL
 void       gtk_widget_unparent            (GtkWidget           *widget);
 GDK_AVAILABLE_IN_ALL
 void       gtk_widget_show                (GtkWidget           *widget);
@@ -375,6 +355,15 @@ GDK_AVAILABLE_IN_ALL
 void       gtk_widget_class_add_shortcut  (GtkWidgetClass      *widget_class,
                                            GtkShortcut         *shortcut);
 
+GDK_AVAILABLE_IN_ALL
+void       gtk_widget_class_set_activate_signal                 (GtkWidgetClass *widget_class,
+                                                                 guint           signal_id);
+GDK_AVAILABLE_IN_ALL
+void       gtk_widget_class_set_activate_signal_from_name       (GtkWidgetClass *widget_class,
+                                                                 const char     *signal_name);
+GDK_AVAILABLE_IN_ALL
+guint      gtk_widget_class_get_activate_signal                 (GtkWidgetClass *widget_class);
+
 GDK_AVAILABLE_IN_ALL
 gboolean   gtk_widget_mnemonic_activate   (GtkWidget           *widget,
                                            gboolean             group_cycling);
